shabottom-rs
Rust port of the most cryptographically secure checksumming algorithm. The algorithm was slightly modified into version 0.2 to be platform-independent.
Usage
The library has some simple functions, see docs.rs.
The CLI tool reads from the file specified with the first argument, or from standard input if “-” or no argument is provided.
License
MIT.
Functions
- shabottom
- Runs shabottom on a file, or on the standard input if “-” is given.
- shabottom_
from_ sum - Creates the shabottom output from a precomputed file sum.c
- sum_
file_ bytes - Creates the 32-bit sum of all file contents, the first step in creating the hash.